@@ -76,9 +76,9 @@ import com.openexchange.exception.OXException;
 import com.openexchange.mail.dataobjects.IDMailMessage;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.mime.ContentType;
+import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeTypes;
-import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MimeMessageConverter;
 import com.openexchange.mail.mime.utils.MimeMessageUtility;
@@ -216,7 +216,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
 
     @Override
     protected String getDebugInfo(final int argsIndex) {
-        final StringBuilder sb = new StringBuilder(command.length() + 64);
+        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(command.length() + 64);
         if (uid) {
             sb.append("UID ");
         }
@@ -248,7 +248,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
 
     @Override
     protected String getCommand(final int argsIndex) {
-        final StringBuilder sb = new StringBuilder(args[argsIndex].length() + 64);
+        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(args[argsIndex].length() + 64);
         if (uid) {
             sb.append("UID ");
         }
@@ -323,7 +323,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
             if (WARN) {
                 final OXException imapExc = MimeMailException.handleMessagingException(e);
                 LOG.warn(
-                    new StringBuilder(128).append("Message #").append(mail.getSeqnum()).append(" discarded: ").append(imapExc.getMessage()).toString(),
+                    new com.openexchange.java.StringAllocator(128).append("Message #").append(mail.getSeqnum()).append(" discarded: ").append(imapExc.getMessage()).toString(),
                     imapExc);
             }
             error = true;
@@ -333,7 +333,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
              */
             if (WARN) {
                 LOG.warn(
-                    new StringBuilder(128).append("Message #").append(mail.getSeqnum()).append(" discarded: ").append(e.getMessage()).toString(),
+                    new com.openexchange.java.StringAllocator(128).append("Message #").append(mail.getSeqnum()).append(" discarded: ").append(e.getMessage()).toString(),
                     e);
             }
             error = true;
@@ -494,7 +494,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
                 h = new InternetHeaders();
                 if (null == headerStream) {
                     if (logger.isDebugEnabled()) {
-                        logger.debug(new StringBuilder(32).append("Cannot retrieve headers from message #").append(msg.getSeqnum()).append(
+                        logger.debug(new com.openexchange.java.StringAllocator(32).append("Cannot retrieve headers from message #").append(msg.getSeqnum()).append(
                             " in folder ").append(msg.getFolder()).toString());
                     }
                 } else {
@@ -778,7 +778,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
         @Override
         public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws OXException {
             final BODYSTRUCTURE bs = (BODYSTRUCTURE) item;
-            final StringBuilder sb = new StringBuilder();
+            final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator();
             sb.append(bs.type).append('/').append(bs.subtype);
             if (bs.cParams != null) {
                 sb.append(bs.cParams);
@@ -868,76 +868,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
      * @return The FETCH items to craft a FETCH command
      */
     private static String getFetchCommand(final boolean isRev1, final FetchProfile fp, final boolean loadBody) {
-        final StringBuilder command = new StringBuilder(128);
-        final boolean envelope;
-        if (fp.contains(FetchProfile.Item.ENVELOPE)) {
-            if (loadBody) {
-                command.append("INTERNALDATE");
-                envelope = false;
-            } else {
-                command.append("ENVELOPE INTERNALDATE RFC822.SIZE");
-                envelope = true;
-            }
-        } else {
-            command.append("INTERNALDATE");
-            envelope = false;
-        }
-        if (fp.contains(FetchProfile.Item.FLAGS)) {
-            command.append(" FLAGS");
-        }
-        if (fp.contains(FetchProfile.Item.CONTENT_INFO)) {
-            command.append(" BODYSTRUCTURE");
-        }
-        if (fp.contains(UIDFolder.FetchProfileItem.UID)) {
-            command.append(" UID");
-        }
-        boolean allHeaders = false;
-        if (fp.contains(IMAPFolder.FetchProfileItem.HEADERS) && !loadBody) {
-            allHeaders = true;
-            if (isRev1) {
-                command.append(" BODY.PEEK[HEADER]");
-            } else {
-                command.append(" RFC822.HEADER");
-            }
-        }
-        if (!envelope && fp.contains(IMAPFolder.FetchProfileItem.SIZE)) {
-            command.append(" RFC822.SIZE");
-        }
-        /*
-         * If we're not fetching all headers, fetch individual headers
-         */
-        if (!allHeaders && !loadBody) {
-            final String[] hdrs = fp.getHeaderNames();
-            if (hdrs.length > 0) {
-                command.append(' ');
-                if (isRev1) {
-                    command.append("BODY.PEEK[HEADER.FIELDS (");
-                } else {
-                    command.append("RFC822.HEADER.LINES (");
-                }
-                command.append(hdrs[0]);
-                for (int i = 1; i < hdrs.length; i++) {
-                    command.append(' ');
-                    command.append(hdrs[i]);
-                }
-                if (isRev1) {
-                    command.append(")]");
-                } else {
-                    command.append(')');
-                }
-            }
-        }
-        if (loadBody) {
-            /*
-             * Load full message
-             */
-            if (isRev1) {
-                command.append(" BODY.PEEK[]");
-            } else {
-                command.append(" RFC822");
-            }
-        }
-        return command.toString();
+        return MailMessageFetchIMAPCommand.getFetchCommand(isRev1, fp, loadBody);
     }
 
     /**
