@@ -57,7 +57,7 @@ import java.net.UnknownHostException;
 import java.util.Collections;
 import java.util.Map;
 import javax.mail.MessagingException;
-import javax.mail.internet.IDNA;
+import javax.mail.internet.idn.IDNA;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
 import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPCapabilities;
@@ -293,7 +293,7 @@ public final class IMAPConfig extends MailConfig {
 
     /**
      * Sets the ACL flag.
-     * 
+     *
      * @param acl <code>true</code> if ACL extension is supported; otherwise <code>false</code>
      */
     public void setAcl(boolean acl) {
